nested_lists.pdf

## Metadata

Title | nested_lists.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\nested_lists.pdf
Pages | 0,1
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403060026+01'00'
PDF Metadata: modDate | D:20230403060026+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0
2. Page 1

#### Page 0

No images

#### Page 1

No images

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 512.3800048828125
y1 |  | 596.831298828125
y0 |  | 529.5177001953125
x0 |  | 108.0199966430664

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 484.7480163574219
y1 |  | 223.79135131835938
y0 |  | 115.10769653320312
x0 |  | 126.0199966430664

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 514.4200439453125
y1 |  | 265.2213439941406
y0 |  | 225.50772094726562
x0 |  | 90.02400207519531

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 514.4200439453125
y1 |  | 514.0013427734375
y0 |  | 391.5177307128906
x0 |  | 90.02400207519531

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 484.7480163574219
y1 |  | 734.851318359375
y0 |  | 612.34765625
x0 |  | 126.0199966430664

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 217.97000122070312
y1 |  | 762.36767578125
y0 |  | 750.36767578125
x0 |  | 144.02000427246094

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

4. In corporis sapiente qui commodi alias in autem delectus eum omnis reprehenderit!

5. Ea culpa vero cum iusto sequi.

6. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. In corporis sapiente qui commodi alias in autem delectus eum omnis reprehenderit!

2. Ea culpa vero cum iusto sequi.

3. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

4. In corporis sapiente qui commodi alias in autem delectus eum omnis reprehenderit!

5. Ea culpa vero cum iusto sequi.

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque

   placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

4. In corporis sapiente qui commodi alias in autem delectus eum omnis

reprehenderit!

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

4. In corporis sapiente qui commodi alias in autem delectus eum omnis reprehenderit!

5. Ea culpa vero cum iusto sequi.

6. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. In corporis sapiente qui commodi alias in autem delectus eum omnis reprehenderit!

2. Ea culpa vero cum iusto sequi.

3. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

4. In corporis sapiente qui commodi alias in autem delectus eum omnis reprehenderit!

5. Ea culpa vero cum iusto sequi.

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

1. Qui dignissimos quasi et nihil dolor aut consequuntur eaque qui neque

   placeat?

2. Aut cumque saepe est voluptatem asperiores sit enim accusamus!

3. Ut amet error et veritatis dolor.

4. In corporis sapiente qui commodi alias in autem delectus eum omnis

reprehenderit!

Path: | content.1.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 434.4700012207031
y1 |  | 113.39131927490234
y0 |  | 73.70773315429688
x0 |  | 126.0199966430664

Path: | content.1.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 458.302001953125
y1 |  | 223.79135131835938
y0 |  | 128.90774536132812
x0 |  | 108.0199966430664

Path: | content.1.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 398.4700012207031
y1 |  | 251.42135620117188
y0 |  | 239.33773803710938
x0 |  | 90.02400207519531

Path: | content.1.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 496.4200134277344
y1 |  | 334.2213439941406
y0 |  | 266.9377136230469
x0 |  | 72.02400207519531

1. Ea culpa vero cum iusto sequi.

2. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. In corporis sapiente qui commodi alias in autem delectus eum omnis

   reprehenderit!

2. Ea culpa vero cum iusto sequi.

3. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

f) Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. In corporis sapiente qui commodi alias in autem delectus eum omnis reprehenderit!

2. Ea culpa vero cum iusto sequi.

3. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. Ea culpa vero cum iusto sequi.

2. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. In corporis sapiente qui commodi alias in autem delectus eum omnis

   reprehenderit!

2. Ea culpa vero cum iusto sequi.

3. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

f) Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

1. In corporis sapiente qui commodi alias in autem delectus eum omnis reprehenderit!

2. Ea culpa vero cum iusto sequi.

3. Cum iusto aliquid aut quisquam nihil qui voluptas maiores.

Parent File Contents